
# Type: functional association_subject




URI: [biolink:functional_association_subject](https://w3id.org/biolink/vocab/functional_association_subject)


## Domain and Range

[FunctionalAssociation](FunctionalAssociation.md) ->  <sub>REQ</sub> [MacromolecularMachine](MacromolecularMachine.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [gene to go term association➞subject](gene_to_go_term_association_subject.md)

## Used by

 * [FunctionalAssociation](FunctionalAssociation.md)
 * [MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md)
 * [MacromolecularMachineToCellularComponentAssociation](MacromolecularMachineToCellularComponentAssociation.md)
 * [MacromolecularMachineToMolecularActivityAssociation](MacromolecularMachineToMolecularActivityAssociation.md)
